@@ -25,13 +25,15 @@
 #include <hildon/hildon.h>
 
 static GdkImage *image;
+#ifndef DIABLO
 static HildonAnimationActor *actor;
+#endif
 static GtkWidget *window, *drawing;
 static unsigned char keymap[65536];
 void *pl_vout_buf;
 int accel=0;
-static int sens, y_def;
-#include "externs.h"
+static int sens,y_def;
+
 enum gpsp_key {
   GKEY_UP       = 1 << 0,
   GKEY_LEFT     = 1 << 1,
@@ -64,7 +66,7 @@ u32 button_plat_mask_to_config[PLAT_BUTTON_COUNT] =
   GKEY_R,
   GKEY_A,
   GKEY_B,
-  GKEY_X
+  GKEY_X,
 };
 
 u32 gamepad_config_map[PLAT_BUTTON_COUNT] =
@@ -82,12 +84,6 @@ u32 gamepad_config_map[PLAT_BUTTON_COUNT] =
   BUTTON_ID_FASTFORWARD
 };
 
-void hildon_quit()
-{
-	gtk_main_quit();
-	exit(0);
-}
-
 
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof(x[0]))
 int gkeystate=0;
@@ -97,6 +93,12 @@ inline u32 gpsp_plat_joystick_read(void)
   return gkeystate;
 }
 char current_savestate_filename[512];
+
+void hild_quit()
+{
+	gtk_main_quit();
+	exit(0);
+}
  
 static void
 window_key_proxy(GtkWidget *widget,GdkEventKey *event,gpointer user_data)
@@ -122,7 +124,7 @@ window_key_proxy(GtkWidget *widget,GdkEventKey *event,gpointer user_data)
 	 get_savestate_filename_noshot(savestate_slot,current_savestate_filename);
      save_state(current_savestate_filename, pl_vout_buf);break;
 	case 17:
-	hildon_quit();
+	hild_quit();
     break;
 	}
 	if (key1==-1)return;
@@ -134,6 +136,9 @@ window_key_proxy(GtkWidget *widget,GdkEventKey *event,gpointer user_data)
 	
 }
 
+
+#include "externs.h"
+
 int maemo_init(int *argc, char **argv)
 {
   int ret, w, h;
@@ -151,20 +156,22 @@ int maemo_init(int *argc, char **argv)
 		}
 		fclose(pFile);
 	}
+sens=150;y_def=150;
 
-		sens=150;
-		y_def=500; //near 45 degrees =)
 
   
   gtk_init (argc, &argv);
-
+#ifdef DIABLO
+window = hildon_window_new ();
+#else
 window = hildon_stackable_window_new ();
+#endif
 gtk_widget_realize (window);
 gtk_window_fullscreen (GTK_WINDOW(window));
 
 g_signal_connect (G_OBJECT (window), "key-press-event",G_CALLBACK (window_key_proxy), NULL);
 g_signal_connect (G_OBJECT (window), "key-release-event",G_CALLBACK (window_key_proxy), NULL);
-g_signal_connect (G_OBJECT (window), "delete_event",G_CALLBACK (hildon_quit), NULL);
+g_signal_connect (G_OBJECT (window), "delete_event",G_CALLBACK (hild_quit), NULL);
 
 gtk_widget_add_events (window,GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 
@@ -202,7 +209,7 @@ gtk_widget_add_events (window,GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
   // ========================================================================
   
   
-char * rom="";
+char * rom;
   
 char ready_to_go=0;
   if(*argc > 1)
@@ -367,7 +374,7 @@ void fb_set_mode(int w, int h, int buffers, int scale, int filter)
 #ifdef DIABLO
 	GdkPixbuf *pixbuf =	gtk_image_get_pixbuf(GTK_IMAGE(image));
 	gtk_window_resize (GTK_WINDOW (drawing), lw, lh);
-	pixbuf = gdk_pixbuf_scale_simple(pixbuf, drawing->allocation.width, drawing->allocation.height, InterpNearest);
+	pixbuf = gdk_pixbuf_scale_simple(pixbuf, drawing->allocation.width, drawing->allocation.height, 1);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(drawing), pixbuf);
 #else
 	gtk_window_resize (GTK_WINDOW (actor), w, h);
