@@ -244,7 +244,7 @@ int main(int argc, char *argv[])
 
 #ifndef PC_BUILD
 #ifdef MAEMO
- gpsp_plat_init(&argc, &argv);
+ return maemo_init(&argc, argv);
 #else
  gpsp_plat_init();
 #endif
